changeset 1177:b1a826c854f0

Updated
author boisy
date Sun, 25 May 2003 15:49:45 +0000
parents b84b382c4a43
children 900ceed1880a
files 3rdparty/drivers/ide/idedesc.asm 3rdparty/drivers/ide/makefile
diffstat 2 files changed, 4 insertions(+), 31 deletions(-) [+]
line wrap: on
line diff
--- a/3rdparty/drivers/ide/makefile	Sun May 25 15:46:20 2003 +0000
+++ b/3rdparty/drivers/ide/makefile	Sun May 25 15:49:45 2003 +0000
@@ -3,30 +3,21 @@
 include ../../../Makefile.rules
 
 DEPENDS		= ./Makefile
-DRVRS		= ccide_l1.dr ccide_l2.dr superide_l1.dr superide_l2.dr
+DRVRS		= ccide_l1.dr ccide_l2.dr
 DESCS		= h0_ide_l1.dd h0_ide_l2.dd h1_ide_l1.dd h1_ide_l2.dd dd_ide_l1.dd dd_ide_l2.dd
-SUPERDESCS	= h0_superide_l1.dd h0_superide_l2.dd h1_superide_l1.dd h1_superide_l2.dd \
-		dd_superide_l1.dd dd_superide_l2.dd
-ALLOBJS		= $(DRVRS) $(DESCS) $(SUPERDESCS)
+ALLOBJS		= $(DRVRS) $(DESCS)
 IDEL1FLAGS	= $(AFLAGS) -aLevel=1
 IDEL2FLAGS	= $(AFLAGS) -aLevel=2
 
 all:	$(ALLOBJS) $(DEPENDS)
 
 # Drivers
-# SuperIDE=1 selects code to work with Cloud-9's SuperIDE product
 ccide_l1.dr: ccide.asm
 	$(AS) $(ASOUT)$@ $< $(IDEL1FLAGS)
 
 ccide_l2.dr: ccide.asm
 	$(AS) $(ASOUT)$@ $< $(IDEL2FLAGS)
 
-superide_l1.dr: ccide.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL1FLAGS) -aSuperIDE=1
-
-superide_l2.dr: ccide.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL2FLAGS) -aSuperIDE=1
-
 # Descriptors
 # ITDRV is the Master(0)/Slave(1) switch for device descriptors
 h0_ide_l1.dd: idedesc.asm
@@ -47,24 +38,6 @@
 dd_ide_l2.dd: idedesc.asm
 	$(AS) $(ASOUT)$@ $< $(IDEL2FLAGS) -aITDRV=0
 
-h0_superide_l1.dd: idedesc.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL1FLAGS) -aSuperIDE=1 -aITDRV=0 -aADDR=65376
-
-h0_superide_l2.dd: idedesc.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL2FLAGS) -aSuperIDE=1 -aITDRV=0 -aADDR=65376
-
-h1_superide_l1.dd: idedesc.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL1FLAGS) -aSuperIDE=1 -aITDRV=1 -aADDR=65376
-
-h1_superide_l2.dd: idedesc.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL2FLAGS) -aSuperIDE=1 -aITDRV=1 -aADDR=65376
-
-dd_superide_l1.dd: idedesc.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL1FLAGS) -aSuperIDE=1 -aITDRV=0 -aADDR=65376
-
-dd_superide_l2.dd: idedesc.asm
-	$(AS) $(ASOUT)$@ $< $(IDEL2FLAGS) -aSuperIDE=1 -aITDRV=0 -aADDR=65376
-
 clean:
 	$(RM) $(ALLOBJS)
--- a/3rdparty/drivers/ide/idedesc.asm	Sun May 25 15:46:20 2003 +0000
+++ b/3rdparty/drivers/ide/idedesc.asm	Sun May 25 15:49:45 2003 +0000
@@ -1,5 +1,5 @@
 ********************************************************************
 * H0 - IDE device descriptor
 *
 * $Id$
 *
@@ -8,7 +8,7 @@
 * Ed.    Comments                                       Who YY/MM/DD
 * ------------------------------------------------------------------
 
-         nam   H0        
+         nam   IDEDesc        
          ttl   IDE device descriptor
 
 * IT.STP (offset $14)
@@ -1,5 +1,5 @@
 ********************************************************************
-* H0 - IDE device descriptor
+* IDEDesc - IDE device descriptor
 *
 * $Id$